%define name		jedit
%define Name		jEdit
%define	major		4
%define minor		2
%define pre		pre14
%define rel		1jpp
%define version		%{major}.%{minor}
%define relpre		0.%{pre}.%{rel}
%if %{?pre:1}%{!?pre:0}
%define release		%{relpre}
%else
%define release		%{rel}
%endif
%define Summary		Open Source programmer's text editor
%define section		free

Name:		%{name}
Version:	%{version}
Release:	%{release}
Epoch:		0
Summary:	%{Summary}
License:	GPL
Group:		Text Editors
Source0:	http://download.sourceforge.net/jedit/jedit42pre14source.tar.gz
Source1:	%{name}-16.png
Source2:	%{name}-32.png
Source3:	%{name}-48.png
Patch0:		%{name}-installer.patch
Patch1:		%{name}-man.patch
Patch2:		%{name}-crosslink.patch
URL:		http://www.jedit.org/
Requires:	aelfred
Requires:	asm
Requires:	bsh2
Requires:	bsh2-classgen
Requires:	gnu.regexp
Requires:	jpackage-utils >= 0:1.5
BuildRequires:	ant
BuildRequires:	aelfred
BuildRequires:	asm
BuildRequires:	bsh2
BuildRequires:	bsh2-classgen
BuildRequires:	gnu.regexp
BuildRequires:	%{_bindir}/xsltproc
BuildRequires:	docbook-style-xsl
BuildRequires:	java-javadoc
BuildArch:	noarch
Obsoletes:	%{name}-rhmenu
BuildRoot:	%{_tmppath}/%{name}-%{version}-root
Vendor:		JPackage Project
Distribution:	JPackage

%description
jEdit is a programmer's text editor written in Java, being developed by Slava
Pestov and others.

Some of jEdit's features include:

    * Built-in macro language (BeanShell).
    * Extensible plugin architecture, with more than 60 plugins available.
    * Plugins can be downloaded and installed from within jEdit using the
      "plugin manager" feature.
    * Syntax highlighting for 70 languages.
    * Supports a large number of character encodings including UTF8 and
      Unicode.
    * Auto-indenting of source code.
    * Folding (indent and 'marker' based).
    * Word wrap.
    * Unlimited undo/redo.
    * Highly configurable and customizable.
    * Every other feature, both basic and advanced, you would expect to
      find in a text editor.

You can find a complete listing of features here.

jEdit is released under the terms of the GNU General Public License.

#%package manual
#Summary:        Manual for %{name}
#Group:          Development/Java
#
#%description manual
#Documentation for %{name}.

%package javadoc
Summary:	Javadoc for %{name}
Group:		Development/Documentation

%description javadoc
Javadoc for %{name}.

%package mdkmenu
Summary:	Mandrake menu entry for %{name}
Group:		Development
Requires:	%{name} = %{epoch}:%{version}

%description mdkmenu
This is a Mandrake menu system entry for %{name}.


%prep
%setup -q -n jEdit
%patch0 -p1
%patch1 -p1
%patch2 -p0
# remove all included external sources
rm -rf bsh
rm -rf com
rm -rf gnu
rm -rf org/objectweb

%build
JAVA_HOME=%java_home

export CLASSPATH=$(build-classpath aelfred asm bsh2/bsh-classgen bsh2/bsh-commands bsh2/bsh-core bsh2/bsh-reflect gnu.regexp)
#export CLASSPATH=$(build-classpath aelfred gnu.regexp)

# compress jedit.jar
perl -p -i -e 's|compress="false"|compress="true"|' build.xml
perl -p -i -e 's|app.version=.*|app.version=%{version}-%{release}|' installer/install.props
ant

DOCBOOK_XSL=`rpm -ql docbook-style-xsl | grep /html/chunk.xsl \
| sed 's|/html/chunk.xsl||'`

if [ -z $DOCBOOK_XSL ]; then
  echo "Unable to find docbook xsl directory"
  exit 1
fi

if [ -z "$SGML_CATALOG_FILES" -a -e %{_sysconfdir}/sgml/catalog ] ; then
  export SGML_CATALOG_FILES=%{_sysconfdir}/sgml/catalog
fi

ant -Ddocbook.xsl=$DOCBOOK_XSL docs-html-xsltproc dist

# Build LatestVersion.jar
(cd jars/LatestVersion && ant)

# Build QuickNotepad.jar
(cd jars/QuickNotepad && ant)

# Create installer filelists
sh installer/mk_filelist.sh

# TODO: crosslink with gnu.regexp and bsh2 when they have non-versioned dirs
ant -Dj2se.api=%{_javadocdir}/java javadoc

%install
rm -rf $RPM_BUILD_ROOT
export JAVA_HOME=%{java_home}
export CLASSPATH=.
%java installer.Install auto $RPM_BUILD_ROOT%{_datadir}/%{name} \
unix-man=$RPM_BUILD_ROOT%{_mandir}/man1
(cd $RPM_BUILD_ROOT%{_datadir}/%{name}/doc && ln -sf %{_javadocdir}/%{name} api)

# manual
#rm -rf $RPM_BUILD_ROOT%{_datadir}/%{name}/doc/users-guide
#find doc/users-guide -type f ! -name "*.html" -exec rm -f {} \;
#(cd $RPM_BUILD_ROOT%{_datadir}/%{name}/doc && ln -sf %{_docdir}/%{name}-manual-%{version} users-guide)

# script
install -d -m 755 $RPM_BUILD_ROOT%{_bindir}
cat > $RPM_BUILD_ROOT%{_bindir}/%{name} << EOF
#!/bin/sh
#
# jedit script
# JPackage Project <http://www.jpackage.org/>

# Source functions library
. %{_datadir}/java-utils/java-functions

# Source system prefs
if [ -f %{_sysconfdir}/%{name}.conf ] ; then
  . %{_sysconfdir}/%{name}.conf
fi

# Source user prefs
if [ -f \$HOME/.%{name}rc ] ; then
  . \$HOME/.%{name}rc
fi

# Configuration
MAIN_CLASS="org.gjt.sp.jedit.jEdit"
BASE_FLAGS="-Dbsh.jedit=true -Djedit.home=%{_datadir}/%{name} -mx32m"

BASE_JARS="aelfred asm bsh2/bsh-classgen bsh2/bsh-commands bsh2/bsh-core bsh2/bsh-reflect bsh2/bsh-util gnu.regexp %{name}"
#BASE_JARS="aelfred gnu.regexp %{name}"

# Set parameters
set_jvm
set_classpath \$BASE_JARS
set_flags \$BASE_FLAGS

# Let's start
run "\$@"
EOF

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr doc/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink

# mdk icons
install -D -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{_liconsdir}/%{name}.png
install -D -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{_iconsdir}/%{name}.png
install -D -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{_miconsdir}/%{name}.png

# mdk menu
install -d -m 755 $RPM_BUILD_ROOT%{_menudir}
cat >$RPM_BUILD_ROOT%{_menudir}/%{name} <<EOF
?package(%{name}):\
 command="%{_bindir}/%{name}"\
 needs="X11"\
 section="Applications/Editors"\
 mimetypes="text/html;text/plain"\
 title="%{Name}"\
 longtitle="%{Summary}"\
 icon="%{name}.png"
EOF

# icons
install -D -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
install -D -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
install -D -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/pixmaps
ln -s %{_datadir}/icons/hicolor/48x48/apps/%{name}.png \
  $RPM_BUILD_ROOT%{_datadir}/pixmaps/%{name}.png

# freedesktop.org menu entry
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/applications
cat >$RPM_BUILD_ROOT%{_datadir}/applications/jpackage-%{name}.desktop <<EOF
[Desktop Entry]
Name=%{Name}
Comment=%{Summary}
Exec=%{_bindir}/%{name}
Terminal=false
Type=Application
Icon=%{name}.png
MimeType=text/english;text/plain;text/x-makefile;text/x-c++hdr;text/x-c++src;text/x-chdr;text/x-csrc;text/x-java;text/x-moc;text/x-pascal;text/x-tcl;text/x-tex;application/x-shellscript;text/x-c;text/x-c++;text/html;text/xml;text/x-xslfo;text/css;text/x-perl;text/x-python;text/sgml;text/x-diff;
Encoding=UTF-8
Categories=Application;Development;TextEditor;Java;X-JPackage;
EOF

# jar
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -m 644 %{name}.jar \
$RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do \
ln -sf ${jar} ${jar/-%{version}/}; done)
(cd $RPM_BUILD_ROOT%{_datadir}/%{name} && \
ln -sf %{_javadir}/%{name}.jar %{name}.jar)

%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
rm -f %{_javadocdir}/%{name}
ln -s %{name}-%{version} %{_javadocdir}/%{name}

%post mdkmenu
%{update_menus}

%postun mdkmenu
%{clean_menus}

%files
%defattr(0644,root,root,0755)
%attr(0755,root,root) %{_bindir}/%{name}
%{_javadir}/*
%{_datadir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_datadir}/applications/*%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/pixmaps/*

#%files manual
#%defattr(0644,root,root,0755)
#%doc doc/users-guide/*

%files javadoc
%defattr(0644,root,root,0755)
%doc %{_javadocdir}/%{name}-%{version}
%ghost %doc %{_javadocdir}/%{name}

%files mdkmenu
%defattr(0644,root,root,0755)
%{_menudir}/%{name}
%{_iconsdir}/%{name}.png
%{_miconsdir}/%{name}.png
%{_liconsdir}/%{name}.png


%changelog
* Mon Jun  7 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:4.2-0.pre14.1jpp
- Update to 4.2pre14.

* Sat May 22 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:4.2-0.pre13.1jpp
- Update to 4.2pre13.
- Drop %%{release} from -mdkmenu versioned dependency to the main package.

* Tue May  4 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:4.2-0.pre12.1jpp
- Update to 4.2pre12.
- Add bunch of MIME types to freedesktop.org menu entry.
- Convert specfile to UTF-8.
- Fix doc path in man page.
- Crosslink with local J2SE javadocs.

* Fri Apr 16 2004 David Walluck <david@anti-microsoft.org> 0:4.2-0.pre11.1jpp
- 4.2pre11

* Sun Feb 08 2004 David Walluck <david@anti-microsoft.org> 0:4.2-0.pre9.1jpp
- 4.2pre9

* Tue Jan 27 2004 David Walluck <david@anti-microsoft.org> 0:4.2-0.pre8.5jpp
- use external asm and bsh again
- add installer patch
- add man patch

* Sun Jan 25 2004 David Walluck <david@anti-microsoft.org> 0:4.2-0.pre8.4jpp
- don't use asm or bsh2 for now

* Sat Jan 24 2004 David Walluck <david@anti-microsoft.org> 0:4.2-0.pre8.3jpp
- use external bsh2 which has had small patch applied for jedit support
- don't bother installing icons to $RPM_BUILD_DIR

* Sat Jan 24 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:4.2-0.pre8.2jpp
- Obsolete rhmenu subpackage, fix up/create freedesktop.org menu stuff.
- Fix link between online help and javadocs.
- New style versionless javadoc dir symlinking.
- Try to use local docbook DTDs to allow non-networked build.

* Tue Jan 20 2004 David Walluck <david@anti-microsoft.org> 0:4.2-0.pre8.1jpp
- 4.2pre8
- set CLASSPATH in more portable manner
- use %%java maco
- compress jedit.jar

* Sun Nov 02 2003 David Walluck <david@anti-microsoft.org> 0:4.2-0.pre6.1jpp
- 4.2pre6
- 4.2pre5 was actually 4.2pre4source, so I'm going back to macros in the
  Source URL for now
- add epochs
- fix %%defattr

* Wed Sep 10 2003 David Walluck <david@anti-microsoft.org> 0:4.2-0.pre5.1jpp
- 4.2pre5

* Tue Aug 28 2003 David Walluck <david@anti-microsoft.org> 0:4.2-0.pre4.1jpp
- merge changes provided by Jordi Murgo <jordi@lleida.com>
- 4.2pre4
- use jedit bsh for now

* Sun May 04 2003 David Walluck <david@anti-microsoft.org> 0:4.2-0.pre1.2jpp
- fix %%release macro which seems to not be working as it once was
- fix javadoc symlinks

* Fri May 02 2003 David Walluck <david@anti-microsoft.org> 0:4.2-0.pre1.1jpp
- 4.2pre1
- update URL tag

* Mon Apr 21 2003 David Walluck <david@anti-microsoft.org> 0:4.1-4jpp
- include non-versioned javadoc symlinks
- user manual magically works again

* Fri Apr 11 2003 David Walluck <david@anti-microsoft.org> 0:4.1-3jpp
- more JPackage 1.5 updates

* Sun Apr 6 2003 David Walluck <david@anti-microsoft.org> 4.1-2jpp
- update for JPackage 1.5
- user manual broken

* Fri Feb 28 2003 David Walluck <david@anti-microsoft.org> 4.1-1jpp
- 4.1

* Sun Feb 23 2003 David Walluck <david@anti-microsoft.org> 4.1-0.pre11.1jpp
- 4.1pre11
- release tag handles both final and pre releases
- update Url

* Sun Feb 16 2003 David Walluck <david@anti-microsoft.org> 4.1-0.pre10.2jpp
- Requires: jpackage-utils (suggested by Pete Chown
  <Pete.Chown at skygate.co.uk>)
- manpage back (installer has changed)
- install to %%{_datadir}/%%{name} instead of %%{_datadir}/%%{name}/%%{version}
- add real jar in %%{_javadir} and symlink to %%{_datadir}/%%{name}
  (useful for building plugins)

* Fri Feb 14 2003 David Walluck <david@anti-microsoft.org> 4.1-0.pre10.1jpp
- 4.1pre10
- back to auto-install, but no manpage

* Fri Jan 31 2003 David Walluck <david@anti-microsoft.org> 4.1-0.pre9.2jpp
- add user's guide back into the main package

* Fri Jan 31 2003 David Walluck <david@anti-microsoft.org> 4.1-0.pre9.1jpp
- release

* Sun Jan 26 2003 David Walluck <david@anti-microsoft.org> 4.1-0.pre8.4jpp
- add javadocs
- split off users-guide into optional manual package

* Sun Jan 26 2003 David Walluck <david@anti-microsoft.org> 4.1-0.pre8.3jpp
- set JAVA_HOME/bin in PATH (suggested by Ville Skyttä
  <ville.skytta at iki.fi>)
- fixed menu entry summaries (Ville Skyttä <ville.skytta at iki.fi>)

* Sat Jan 25 2003 Ville Skyttä <ville.skytta at iki.fi> - 4.1-0.pre8.2jpp
- (Build)Require jpackage-utils, and use java-functions from it.
- Fixed menu entry summaries.

* Thu Jan 23 2003 David Walluck <david@anti-microsoft.org> 4.1-0.pre8.1jpp
- remove bsh from jedit.jar
- fix release tag

* Mon Jan 20 2003 David Walluck <david@anti-microsoft.org> 4.1-0.8.0jpp
- 4.1pre8
- look for chunk.xsl
- remove aelfred and gnu.regexp from jedit.jar (bsh forthcoming) 

* Mon Oct 07 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 4.0.3-1jpp
- first jpackage release (David Walluck <david@anti-microsoft.org>)
